function result = trapez(intfunc, a, b, N)
%
%  Trapezregel zur Quadratur von integrand
%
%  integrand  Funktion der Form 'function y=integrand(x)'
%  a          untere Intervallgrenze
%  b          obere  Intervallgrenze
%  N+1        Anzahl Stuetzstellen (aequidistant)
%  result     Resultat

h = (b-a)/N;              % Abstand der Stuetzstellen
x = a:h:b;                % Stuezstellen
f = feval(intfunc, x);  % Integrand auf Stuetzstellen auswerten

% Trapezregel auswerten
result = h * ( sum(f) - ( f(1) + f(size(f, 2)) )/2 );  % ueber alles 2* und erste und letzte hoehe einmal -, dann / 2

